from setuptools import setup, find_packages


setup(name='econometrics_tests_statistics',
      version='1.2',
      description='Numerical methods',
      packages=find_packages(),
      author_email='vovalagutov1111@yandex.ru',
      install_requires = ['numpy'],
      zip_safe=False,
      )
